function [ Xftftmat ] = filtfiltpad( bcoeffs, acoeffs, Xmat, Npad, winType )
% HILBERTPAD applies hilbert transform over a padded version of the input
% signal. If Xmat is 2D/3D, time dimension is supposed to lay along columns.

% Xmat is the input signal
% Nfft is the no. points used to approximate hilbert transform
% Npad is the no. points used to pad (Npad/2 before, Npad/2 after)
% winType is the type of window, 'mirror' uses first/last Npad/2 Xmat samples

if nargin<5
     winType='mirror';
     if nargin<4
         Npad=size(Xmat,1)/2;
     end
end

if length(size(Xmat))>3
    error('Padding is not supported for matrices with more than 3D.');
end

M2=size(Xmat,2);
M3=size(Xmat,3);

Npadhalf=floor(Npad/2);

if ~strcmp('mirror',winType)
    Xwinmat=repmat(eval([ winType '(Npad)']),1,M2,M3);
    Xmatpad=[repmat(Xmat(1,:,:),[Npadhalf 1 1]).*Xwinmat(2:Npadhalf+1,:,:); Xmat; repmat(Xmat(end,:,:),[Npadhalf 1 1]).*Xwinmat(end-Npadhalf:end-1,:,:)];
else
    Xmatpad=[flipud(Xmat(2:Npadhalf+1,:,:)); Xmat; flipud(Xmat(end-Npadhalf:end-1,:,:))];
end


%subplot(2,1,1) % UNCOMMENT TO SEE THE PADDING
%plot(1:Npadhalf,Xmatpad(1:Npadhalf,1,1),'r'); hold on;
%plot(Npadhalf+1:Npadhalf+size(Xmat,1),Xmatpad(Npadhalf+1:Npadhalf+size(Xmat,1),1,1),'b');
%plot(Npadhalf+size(Xmat,1)+1:2*Npadhalf+size(Xmat,1),Xmatpad(Npadhalf+size(Xmat,1)+1:end,1,1),'r');

%subplot(2,1,1) % UNCOMMENT TO SEE THE PADDING
%plot(1:size(Xmat,1)+2*Npadhalf,Xmatpad(:,1,1),'r'); hold on;
%plot(Npadhalf+1:Npadhalf+size(Xmat,1),Xmat(:,1,1),'b'); 

Xftftmatpad=filtfilt(bcoeffs,acoeffs,Xmatpad);

Xftftmat=Xftftmatpad(Npadhalf+1:end-Npadhalf,:,:);

%subplot(2,1,2) % UNCOMMENT TO SEE THE FILTERED PADDING
%plot(1:size(Xmat,1)+2*Npadhalf,Xftftmatpad(:,1,1),'r'); hold on;
%plot(Npadhalf+1:Npadhalf+size(Xmat,1),Xftftmat(:,1,1),'b'); 

end

