function [ Xhilbmat ] = hilbertpad( Xmat, Nfft, Npad, winType )
% HILBERTPAD applies hilbert transform over a padded version of the input
% signal. If Xmat is 2D, time dimension is supposed to lay along columns.

% Xmat is the input signal
% Nfft is the no. points used to approximate hilbert transform
% Npad is the no. points used to pad (Npad/2 before, Npad/2 after)
% winType is the type of window, 'mirror' uses first/last Npad/2 Xmat samples

if nargin<4
     winType='mirror';
     if nargin<3
         Npad=floor(size(Xmat,1)/2);
         if nargin<2
            Nfft=size(Xmat,1);
         end
     end
end

M=size(Xmat,2);
Npadhalf=floor(Npad/2);

if ~strcmp('mirror',winType)
    Xwinmat=repmat(eval([ winType '(Npad)']),1,M);
    Xmatpad=[repmat(Xmat(1,:),Npadhalf,1).*Xwinmat(1:Npadhalf,:); Xmat; repmat(Xmat(end,:),Npadhalf,1).*Xwinmat(end-Npadhalf:end-1,:)];
else
    Xmatpad=[flipud(Xmat(2:Npadhalf+1,:)); Xmat; flipud(Xmat(end-Npadhalf:end-1,:))];
end

%subplot(2,1,1) % UNCOMMENT TO SEE THE PADDING
%plot(1:Npadhalf,Xmatpad(1:Npadhalf,1,1),'r'); hold on;
%plot(Npadhalf+1:Npadhalf+size(Xmat,1),Xmatpad(Npadhalf+1:Npadhalf+size(Xmat,1),1,1),'b');
%plot(Npadhalf+size(Xmat,1)+1:2*Npadhalf+size(Xmat,1),Xmatpad(Npadhalf+size(Xmat,1)+1:end,1,1),'r');

Xhilbmatpad=hilbert(Xmatpad,Nfft+Npad);
Xhilbmat=Xhilbmatpad(Npadhalf+1:end-Npadhalf,:);

%subplot(2,1,2) % UNCOMMENT TO SEE THE PADDING
%plot(1:size(Xmat,1)+2*Npadhalf,abs(Xhilbmatpad(:,1,1)),'r'); hold on;
%plot(Npadhalf+1:Npadhalf+size(Xmat,1),abs(Xhilbmat(:,1,1)),'b'); 

end

