function [ Xhilbmat ] = hilbertpaduncut( Xmat, Nfft, Npad, winType )
% HILBERTPAD applies hilbert transform over a padded version of the input
% signal. If Xmat is 2D, time dimension is supposed to lay along columns.

% Xmat is the input signal
% Nfft is the no. points used to approximate hilbert transform
% Npad is the no. points used to pad (Npad/2 before, Npad/2 after)
% winType is the type of window, 'mirror' uses first/last Npad/2 Xmat samples

if nargin<4
     winType='mirror';
     if nargin<3
         Npad=128;
     end
end

M=size(Xmat,2);
Npadhalf=floor(Npad/2);

if ~strcmp('mirror',winType)
    Xwinmat=repmat(eval([ winType '(Npad)']),1,M);
    Xmatpad=[repmat(Xmat(1,:),Npadhalf,1).*Xwinmat(1:Npadhalf,:); Xmat; repmat(Xmat(end,:),Npadhalf,1).*Xwinmat(end-Npadhalf+1:end,:)];
else
    Xmatpad=[-flipud(Xmat(1:Npadhalf,:)); Xmat; -flipud(Xmat(end-Npadhalf+1:end,:))];
end

%size(Xmatpad)
%Npad
%Npadhalf

figure()
subplot(4,1,1)
plot(1:size(Xmatpad,1),Xmatpad(:,1),'b--'); hold on;
plot(Npadhalf+1:size(Xmatpad,1)-Npadhalf,Xmatpad(Npadhalf+1:end-Npadhalf,1),'b-')
title('filtered signal')

subplot(4,1,2)
plot(1:size(Xmatpad,1),abs(Xmatpad(:,1)).^2,'b--'); hold on;
plot(Npadhalf+1:size(Xmatpad,1)-Npadhalf,abs(Xmatpad(Npadhalf+1:end-Npadhalf,1)).^2,'b-')
title('abs(filtered signal)^2')

Xhilbmatpad=hilbert(Xmatpad,Nfft+Npad);

Xhilbmat=Xhilbmatpad;%(Npadhalf+1:end-Npadhalf,:);

subplot(4,1,3)
plot(1:Nfft+Npad,Xhilbmatpad(:,1),'b--'); hold on;
plot(Npadhalf+1:Nfft+Npad-Npadhalf,Xmatpad(Npadhalf+1:Nfft+Npad-Npadhalf,1),'b-')
title('hilbert(filtered signal)')

subplot(4,1,4)
plot(1:Nfft+Npad,abs(Xhilbmatpad(:,1)).^2,'b--'); hold on;
plot(Npadhalf+1:Nfft+Npad-Npadhalf,abs(Xhilbmatpad(Npadhalf+1:Nfft+Npad-Npadhalf,1)).^2,'b-')
title('abs(hilbert(filtered signal))^2')

end

