function  plotmstd(xaxis, yvalues, colorvs, alpha, linespec, linewidth)
%plotmsem plots mean +/- sem with shaded, continuous error bars

if nargin < 6
    if nargin < 5
        if nargin < 4
            if nargin<3
                color=[0 0 0];
            elseif ischar(colorvs)
                color=rem(floor((strfind('kbgcrmyw',colorvs(1))-1)*[.25 .5 1]),2);
                if length(colorvs)>1
                    linespec=colorvs(2:end);
                end
            end
            alpha=.1;
        end
        if length(colorvs)<=1; linespec='-'; end
    end
    linewidth=2;
end

if ~isvector(xaxis)
    error('x-axis vector has to be 1D.');
elseif iscolumn(xaxis)
        xaxis=xaxis';
end

if ~ismatrix(yvalues)
        error('y-values matrix has to be 2D.');
end

if ~any(size(yvalues)==length(xaxis))
    error('x-axis and y-values must have equal size along 1D (at least).');
end

% force xaxis and yvalues to have same number of rows (not columns)
if size(yvalues,2)~=length(xaxis)
    yvalues=yvalues';  
end

% mean and sem are computed along rows
meanyv=nanmean(yvalues,1);
stdyv=nanstd(yvalues,[],1);

fill([xaxis xaxis(end:-1:1)]',[meanyv-stdyv meanyv(end:-1:1)+stdyv(end:-1:1)]',color,'facealpha',alpha,'linestyle','none'); hold on;
plot(xaxis,meanyv,linespec,'Color',color,'Linewidth',linewidth);

end

