function y = rangenorm(x, yedges, xedges)

if nargin<3
    xedges=[min(x(:)) max(x(:))];
    if nargin<2
        yedges=[0 1];
    end
end

% takes in input a vector x and normalizes it to fit the range set by yedges
% eg: x=[2.5414,2.1175,1.9850,1.7856,1.5165,1.4234,0.3996,-0.1658,-1.9447]
%     yedges=[0 1]
%     y=[1.0000, 0.9055, 0.8760, 0.8315, 0.7715, 0.7508, 0.5226, 0.3965, 0]

% NOTE: yedges need to be in increasing order [ymin ymax] 
%       sort is used to prevent erroneous usage.
if ~isvector(xedges)
    error('Wrong input: xedges is not a vector.');
end
if length(xedges)~=2
    error('Wrong input: xedges does not contain 2 elements.');
end
if ~isvector(yedges)
    error('Wrong input: yedges is not a vector.');
end
if length(yedges)>2
    error('Wrong input: yedges does not contain 2 elements.');
end
   
xedges=sort(xedges);
yedges=sort(yedges);

y=(x-xedges(1))/(xedges(2)-xedges(1))*(yedges(2)-yedges(1))+yedges(1);

end